@@ -47,6 +47,7 @@ OC.L10N.register(
     "Restore" : "Аднавіць",
     "Delete permanently" : "Выдаліць назаўжды",
     "Shared calendars" : "Абагуленыя календары",
+    "Internal link" : "Унутраная спасылка",
     "Share link" : "Абагуліць спасылку",
     "Copy public link" : "Скапіяваць публічную спасылку",
     "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
@@ -56,14 +57,21 @@ OC.L10N.register(
     "View" : "Праглядзець",
     "Filename" : "Назва файла",
     "Cancel" : "Скасаваць",
+    "Attachments folder" : "Папка для далучэнняў",
     "Timezone" : "Часавы пояс",
     "Navigation" : "Навігацыя",
     "Actions" : "Дзеянні",
     "Close editor" : "Закрыць рэдактар",
     "General" : "Агульныя",
-    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
-    "Show tasks in calendar" : "Паказаць заданні ў календары",
-    "Show weekends" : "Паказваць уік-энды",
+    "Availability settings" : "Налады даступнасці",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Доступ да календароў Nextcloud з іншых праграм і прылад",
+    "CalDAV URL" : "URL-адрас CalDAV",
+    "Appearance" : "Знешні выгляд",
+    "Birthday calendar" : "Каляндар дзён нараджэння",
+    "Tasks in calendar" : "Заданні ў календары",
+    "Weekends" : "Уік-энды",
+    "Week numbers" : "Нумары тыдняў",
     "Keyboard shortcuts" : "Спалучэнні клавіш",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
@@ -118,6 +126,7 @@ OC.L10N.register(
     "(organizer)" : "(арганізатар)",
     "From" : "З",
     "To" : "Да",
+    "Your Time" : "Ваш час",
     "never" : "ніколі",
     "Resources" : "Рэсурсы",
     "Attendance required" : "Наведванне абавязковае",
@@ -131,6 +140,7 @@ OC.L10N.register(
     "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
     "Global" : "Глабальны",
     "Public calendars" : "Публічныя календары",
+    "Select a date" : "Выберыце дату",
     "Time:" : "Час:",
     "Personal" : "Асабістыя",
     "Show unscheduled tasks" : "Паказаць незапланаваныя заданні",
@@ -174,6 +184,9 @@ OC.L10N.register(
     "Error while sharing file" : "Памылка пры абагульванні файла",
     "User not found" : "Карыстальнік не знойдзены",
     "Calendar name …" : "Назва календара …",
+    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
+    "Show tasks in calendar" : "Паказаць заданні ў календары",
+    "Show weekends" : "Паказваць уік-энды",
     "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
