@@ -1,6 +1,7 @@
 OC.L10N.register(
     "calendar",
     {
+    "Provided email-address is too long" : "Предоставеният e mail адрес е прекалено дълъг",
     "User-Session unexpectedly expired" : "Потребителската сесия неочаквано изтече",
     "Provided email-address is not valid" : "Предоставеният е-мейл адрес е невалиден",
     "%s has published the calendar »%s«" : "%s е публикувал календар »%s«",
@@ -14,17 +15,20 @@ OC.L10N.register(
     "No more events today" : " Няма повече събития за днес",
     "No upcoming events" : "Няма предстоящи събития",
     "More events" : "Повече събития",
+    "%1$s with %2$s" : "%1$sс %2$s",
     "Calendar" : "Календар",
     "New booking {booking}" : "Нова резервация {booking}",
     "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) резервира срещата „{config_display_name}“ на {date_time}.",
     "Appointments" : "Срещи",
     "Schedule appointment \"%s\"" : "Насрочване на среща „%s“",
     "Schedule an appointment" : "Насрочване на среща",
+    "%1$s - %2$s" : "%1$s%2$s",
     "Prepare for %s" : "Подгответе се за %s",
     "Follow up for %s" : "Последващо действие за %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Вашата среща „%s“ с %s, се нуждае от потвърждение",
     "Dear %s, please confirm your booking" : "Уважаеми %s, моля, потвърдете резервацията си",
     "Confirm" : "Потвърдете",
+    "Appointment with:" : "среща с",
     "Description:" : "Описание:",
     "This confirmation link expires in %s hours." : "Тази връзка за потвърждение изтича след %s часа.",
     "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ако все пак желаете да отмените срещата, моля, свържете се с вашият организатор, като отговорите на този имейл или като посетите страницата на профила му.",
@@ -37,15 +41,27 @@ OC.L10N.register(
     "Comment:" : "Коментар:",
     "You have a new appointment booking \"%s\" from %s" : "Имате нова резервация за среща „%s“ от %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Уважаемият/та  %s, %s (%s) резервира среща с вас.",
+    "%s has proposed a meeting" : "%s предложи среща",
+    "%s has updated a proposed meeting" : "%s актуализира предложената среща",
+    "%s has canceled a proposed meeting" : "%sотмени предложената среща",
+    "Dear %s, a new meeting has been proposed" : "Уважаеми %s, предложена е нова среща",
+    "Dear %s, a proposed meeting has been updated" : "Уважаеми %s, предложената среща е актуализирана",
+    "Dear %s, a proposed meeting has been cancelled" : "Уважаеми %s, предложената среща е отменена",
     "Location:" : "Местоположение:",
+    "Duration:" : "Продължителсност:",
+    "%1$s from %2$s to %3$s" : "%1$sот %2$s до%3$s",
+    "Dates:" : "Дати:",
+    "Respond" : "Отговорете",
     "A Calendar app for Nextcloud" : "Календар за Nextcloud",
     "Previous day" : "Вчера",
     "Previous week" : "Миналата седмица",
+    "Previous year" : "Предишна година",
     "Previous month" : "Предишен месец",
     "Next day" : "Утре",
     "Next week" : "Следваща седмица",
     "Next year" : "Следващата година",
     "Next month" : "Следващия месец",
+    "Create new event" : "Създай ново събитие",
     "Event" : "Събитие",
     "Today" : "Днес",
     "Day" : "Ден",
@@ -59,6 +75,7 @@ OC.L10N.register(
     "Copy link" : "Копиране на връзката",
     "Edit" : "Редакция",
     "Delete" : "Изтриване",
+    "Appointment schedules" : "Графици за срещи",
     "Create new" : "Създай нов",
     "Disable calendar \"{calendar}\"" : "Деактивиране на календар „{calendar}“",
     "Disable untitled calendar" : "Деактивиране на неозаглавен календар",
@@ -81,6 +98,8 @@ OC.L10N.register(
     "New calendar with task list" : "Нов календар със списък със задачи",
     "New subscription from link (read-only)" : "Нов абонамент от връзка (само за четене)",
     "Creating subscription …" : "Създаване на абонамент …",
+    "Add public holiday calendar" : "Добавете календар на официалните празници",
+    "Add custom public calendar" : "Добавете персонализиран публичен календар",
     "Calendar link copied to clipboard." : "Връзка за Календара е копирана в клипборда",
     "Calendar link could not be copied to clipboard." : "Връзката за Календара не може да се копира в клипборда",
     "Copy subscription link" : "Копиране на връзката за абониране",
@@ -104,7 +123,11 @@ OC.L10N.register(
     "Delete permanently" : "Изтрий завинаги",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Елементите в кошчето за боклук се изтриват след {numDays} дни","Елементите в кошчето се изтриват след {numDays} дни"],
     "Could not update calendar order." : " Невъзможност да се актуализира записът в календара",
+    "Shared calendars" : "споделени календари",
     "Deck" : "Deck",
+    "Internal link" : "Вътрешна връзка",
+    "A private link that can be used with external clients" : "Частна връзка, която може да се използва с външни клиенти",
+    "Copy internal link" : "Копиране на вътрешна връзка",
     "An error occurred, unable to publish calendar." : "Възникна грешка, невъзможност да се публикува календар.",
     "An error occurred, unable to send email." : "Възникна грешка, невъзможност да се изпрати имейл",
     "Embed code copied to clipboard." : "Кодът за вграждане е копиран в клипборда",
@@ -121,16 +144,28 @@ OC.L10N.register(
     "Could not copy code" : "Кодът не можа да се копира",
     "Delete share link" : "Изтрий споделената връзка",
     "Deleting share link …" : "Изтриване на връзката за споделяне  ...",
+    "{teamDisplayName} (Team)" : "{teamDisplayName}(Екип)",
     "An error occurred while unsharing the calendar." : "Възникна грешка при прекратяване на споделянето на календар.",
     "An error occurred, unable to change the permission of the share." : "Възникна грешка, невъзможност да се промени разрешението за споделяне ",
-    "can edit" : "може да редактира",
+    "can edit and see confidential events" : "може да редактира и вижда поверителни събития",
     "Unshare with {displayName}" : "Прекратява споделянето с {displayName}",
     "Share with users or groups" : "Сподели с потребители или групи",
     "No users or groups" : "Няма потребители или групи",
+    "Failed to save calendar name and color" : "Запазването на името и цвета на календара не бе успешно",
+    "Calendar name …" : "Име на календар ...",
+    "Never show me as busy (set this calendar to transparent)" : "Никога не ме показвай като зает (задай този календар да бъде прозрачен)",
     "Share calendar" : "Споделяне на календар",
     "Unshare from me" : "Прекратяване на споделянето от мен",
     "Save" : "Запазване",
     "No title" : "Без заглавие",
+    "Are you sure you want to delete \"{title}\"?" : "Сигурни ли сте, че искате да изтриете  \"{title}\"?",
+    "Deleting proposal \"{title}\"" : "Предложение за изтриване\"{title}\"",
+    "Successfully deleted proposal" : "Успешно изтриване",
+    "Failed to delete proposal" : "Неуспешно изтриване",
+    "Failed to retrieve proposals" : "Неуспешно извличане",
+    "Meeting proposals" : "Предложения за срещи",
+    "A configured email address is required to use meeting proposals" : "Необходим е конфигуриран имейл адрес, за да се използват предложения за срещи",
+    "No active meeting proposals" : "Няма активни предложения за срещи",
     "View" : "Изглед",
     "Import calendars" : "Импортиране на календари",
     "Please select a calendar to import into …" : "Моля, изберете календар, в който да импортирате",
@@ -139,10 +174,11 @@ OC.L10N.register(
     "Cancel" : "Отказ",
     "_Import calendar_::_Import calendars_" : ["Импортиране на календар","Импортиране на календари"],
     "Select the default location for attachments" : "Избор на местоположение на прикачените файлове по подразбиране",
+    "Pick" : "Избирам",
     "Invalid location selected" : "Избрано е невалидно местоположение",
     "Attachments folder successfully saved." : "Папката с прикачени файлове е записана успешно.",
     "Error on saving attachments folder." : "Грешка при запазване на папката с прикачени файлове.",
-    "Default attachments location" : "Местоположение на прикачените файлове по подразбиране",
+    "Attachments folder" : "Папка с прикачени файлове",
     "{filename} could not be parsed" : "{filename} не можа да бъде анализиран",
     "No valid files found, aborting import" : "Не са намерени валидни файлове, прекъсване на импортирането",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно импортиране на %n събития","Успешно импортиране на %n събития"],
@@ -158,6 +194,7 @@ OC.L10N.register(
     "Day view" : "Дневен изглед",
     "Week view" : "Седмичен изглед",
     "Month view" : "Месечен изглед",
+    "Year view" : "Годишен преглед",
     "List view" : "Списъчен изглед",
     "Actions" : "Действия",
     "Create event" : "Създай събитие",
@@ -169,20 +206,32 @@ OC.L10N.register(
     "Duplicate event" : "Дублирано събитие",
     "or" : "или",
     "Calendar settings" : "Настройки на календар",
+    "At event start" : "В началото на събитието",
     "No reminder" : "Без напомняне",
+    "Failed to save default calendar" : "Неуспешно записване на календарът по подразбиране",
     "CalDAV link copied to clipboard." : "Копиране на CalDAV връзка в клипборда",
     "CalDAV link could not be copied to clipboard." : "CalDAV връзката не може да бъде копирана в клипборда",
     "General" : "Общи",
-    "Personal availability settings" : "Настройки за лична достъпност",
-    "Copy primary CalDAV address" : "Копиране на основния CalDAV адрес",
+    "Availability settings" : "Настройки за наличност",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Достъп до календари на Nextcloud от други приложения и устройства",
+    "CalDAV URL" : "CalDAV URL",
     "Copy iOS/macOS CalDAV address" : "Копиране iOS/macOS CalDAV адрес",
-    "Enable birthday calendar" : "Активиране на календара за рожден ден",
-    "Show tasks in calendar" : "Показване на задачите в календара",
-    "Show weekends" : "Покажи събота и неделя",
-    "Show week numbers" : "Показвай номерата на седмиците",
+    "Appearance" : "Изглед",
+    "Birthday calendar" : "Календар за рожден ден",
+    "Tasks in calendar" : "Задачи в календар",
+    "Weekends" : "Почивни дни",
+    "Week numbers" : "Номера на седмиците",
+    "Limit number of events shown in Month view" : "Ограничаване на броя на събитията, показвани в месечния изглед",
+    "Density in Day and Week View" : "Натовареност на дневен и седмичен изглед",
     "Editing" : "Редактиране",
+    "Simple event editor" : "Опростен редактор на събития",
+    "\"More details\" opens the detailed editor" : "„Повече детайли“ отваря подробния редактор",
+    "Default calendar for incoming invitations" : "Календар по подразбиране за входящи покани",
     "Default reminder" : "Напомняне по подразбиране",
     "Keyboard shortcuts" : "Бързи клавиши",
+    "Appointment schedule successfully created" : "Графикът на срещите е създаден успешно",
+    "Appointment schedule successfully updated" : "Графикът на срещите бе актуализиран успешно",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} минути","{duration} минути"],
     "0 minutes" : "0 минути",
     "_{duration} hour_::_{duration} hours_" : ["{duration} часа","{duration} минути"],
@@ -193,6 +242,9 @@ OC.L10N.register(
     "To configure appointments, add your email address in personal settings." : "За конфигуриране на срещи, добавете своя имейл адрес в личните настройки.",
     "Public – shown on the profile page" : "Публичен – показва се на страницата на профила",
     "Private – only accessible via secret link" : "Частен – достъпен само чрез тайна връзка",
+    "Appointment schedule saved" : "Графикът на срещите е запазен",
+    "Create appointment schedule" : "Създайте график за срещи",
+    "Edit appointment schedule" : "Редактирайте графика за срещи",
     "Update" : "Обновяване",
     "Appointment name" : "Име на срещата",
     "Location" : "Местоположение",
@@ -215,6 +267,7 @@ OC.L10N.register(
     "Friday" : "Петък",
     "Saturday" : "Събота",
     "Sunday" : "Неделя",
+    "Weekdays" : "Делнични дни",
     "Add time before and after the event" : "Добавяне на време преди и след събитието",
     "Before the event" : "Преди събитието",
     "After the event" : "След събитието",
@@ -222,12 +275,19 @@ OC.L10N.register(
     "Minimum time before next available slot" : "Минимално време преди следващия наличен слот",
     "Max slots per day" : "Максимален брой слотове на ден",
     "Limit how far in the future appointments can be booked" : "Ограничение, колко далеч в бъдеще могат да бъдат резервирани срещи",
+    "It seems a rate limit has been reached. Please try again later." : "Изглежда е достигнат лимит на скоростта. Моля, опитайте отново по-късно.",
     "Please confirm your reservation" : "Моля, потвърдете вашата резервация",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Изпратихме ви имейл с подробности. Моля, потвърдете вашата среща, като използвате връзката в имейла. Можете да затворите тази страница сега.",
     "Your name" : "Вашето име",
     "Your email address" : "Вашият имейл адрес",
     "Please share anything that will help prepare for our meeting" : "Моля, споделете всичко, което ще помогне да се подготвим за нашата среща",
     "Could not book the appointment. Please try again later or contact the organizer." : "Срещата не можа да резервира. Моля, опитайте отново по-късно или се свържете с организатора.",
+    "Back" : "Назад",
+    "Book appointment" : "Резервиране на срещата",
+    "Error fetching Talk conversations." : "Грешка при извличане на гласовите разговори.",
+    "Conversation does not have a valid URL." : "Разговорът няма валиден URL адрес",
+    "Successfully added Talk conversation link to location." : "Връзката към разговора е успешно добавена.",
+    "Successfully added Talk conversation link to description." : "Връзката към разговора е успешно добавена в описанието.",
     "Select conversation" : "Избор на разговор",
     "on" : "на",
     "at" : "в",
@@ -469,7 +529,6 @@ OC.L10N.register(
     "When shared show full event" : "При споделяне, показвай цялото събитие",
     "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
     "When shared hide this event" : "При споделяне, скривай това събитие",
-    "The visibility of this event in shared calendars." : "Видимостта на това събитие в споделени календари.",
     "Add a location" : "Добавяне на местоположение",
     "Status" : "Състояние",
     "Confirmed" : "Потвърдено",
@@ -494,12 +553,21 @@ OC.L10N.register(
     "Appointment not found" : "Срещата не е намерена",
     "User not found" : "Потребителят не е намерен ",
     "Hidden" : "Скрит",
+    "can edit" : "може да редактира",
     "Calendar name …" : "Име на календар ...",
+    "Default attachments location" : "Местоположение на прикачените файлове по подразбиране",
     "Automatic ({detected})" : "Автоматично (detected})",
     "Shortcut overview" : "Преглед на пряк път",
+    "Enable birthday calendar" : "Активиране на календара за рожден ден",
+    "Show tasks in calendar" : "Показване на задачите в календара",
     "Enable simplified editor" : "Активиране на опростен редактор",
     "Limit the number of events displayed in the monthly view" : "Ограничаване на броя на събитията, показвани в месечния изглед",
+    "Show weekends" : "Покажи събота и неделя",
+    "Show week numbers" : "Показвай номерата на седмиците",
     "Time increments" : "Времеви стъпки",
-    "Show keyboard shortcuts" : "Показване на клавишни комбинации"
+    "Copy primary CalDAV address" : "Копиране на основния CalDAV адрес",
+    "Personal availability settings" : "Настройки за лична достъпност",
+    "Show keyboard shortcuts" : "Показване на клавишни комбинации",
+    "The visibility of this event in shared calendars." : "Видимостта на това събитие в споделени календари."
 },
 "nplurals=2; plural=(n != 1);");
