@@ -137,7 +137,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Equip)",
     "An error occurred while unsharing the calendar." : "S'ha produït un error en deixar de compartir el calendari.",
     "An error occurred, unable to change the permission of the share." : "Ha succeït un error i no s'ha pogut canviar els permisos de compartició.",
-    "can edit" : "pot editar-lo",
     "Unshare with {displayName}" : "S'ha deixat de compartir amb {displayName}",
     "Share with users or groups" : "Comparteix amb usuaris o grups",
     "No users or groups" : "No hi ha usuaris ni grups",
@@ -158,7 +157,7 @@ OC.L10N.register(
     "Invalid location selected" : "La ubicació seleccionada no és vàlida",
     "Attachments folder successfully saved." : "La carpeta de fitxers adjunts s'ha desat correctament.",
     "Error on saving attachments folder." : "Error en desar la carpeta de fitxers adjunts.",
-    "Default attachments location" : "Ubicació per defecte dels fitxers adjunts",
+    "Attachments folder" : "Carpeta fitxers adjunts",
     "{filename} could not be parsed" : "No s'ha pogut entendre el contingut del fitxer {filename}",
     "No valid files found, aborting import" : "No s'han trobat fitxers que siguin vàlids i s'ha avortat la importació",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["S'ha importat correctament %n esdeveniment","S'ha importat correctament %n esdeveniments"],
@@ -192,13 +191,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
     "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
     "General" : "General",
-    "Personal availability settings" : "Paràmetres de disponibilitat personal",
-    "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
     "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
-    "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
-    "Show tasks in calendar" : "Mostra les tasques en el calendari",
-    "Show weekends" : "Mostra els caps de setmana",
-    "Show week numbers" : "Mostra el número de la setmana",
+    "Appearance" : "Aparença",
     "Editing" : "Edició",
     "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
     "Default reminder" : "Recordatori per defecte",
@@ -561,7 +555,6 @@ OC.L10N.register(
     "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
     "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
     "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
-    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits.",
     "Add a location" : "Afegeix una ubicació",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Afegeix una descripció\n\n- De què tracta aquesta reunió\n- Elements de l'ordre del dia\n- Qualsevol cosa que els participants hagin de preparar",
     "Status" : "Estat",
@@ -588,12 +581,21 @@ OC.L10N.register(
     "Appointment not found" : "No s'ha trobat la cita",
     "User not found" : "No s'ha trobat l'usuari",
     "Hidden" : "Ocult",
+    "can edit" : "pot editar-lo",
     "Calendar name …" : "Nom del calendari …",
+    "Default attachments location" : "Ubicació per defecte dels fitxers adjunts",
     "Automatic ({detected})" : "Automàtic ({detected})",
     "Shortcut overview" : "Descripció general de la drecera",
+    "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
+    "Show tasks in calendar" : "Mostra les tasques en el calendari",
     "Enable simplified editor" : "Habilitar l'editor simplificat",
     "Limit the number of events displayed in the monthly view" : "Limita el nombre d'esdeveniments que es mostren a la vista mensual",
+    "Show weekends" : "Mostra els caps de setmana",
+    "Show week numbers" : "Mostra el número de la setmana",
     "Time increments" : "Increments de temps",
-    "Show keyboard shortcuts" : "Mostra les dreceres del teclat"
+    "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
+    "Personal availability settings" : "Paràmetres de disponibilitat personal",
+    "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
+    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits."
 },
 "nplurals=2; plural=(n != 1);");
