@@ -131,7 +131,6 @@ OC.L10N.register(
     "Deleting share link …" : "Eliminando enlace compartido …",
     "An error occurred while unsharing the calendar." : "Ocurrió un error al dejar de compartir el calendario.",
     "An error occurred, unable to change the permission of the share." : "Ocurrió un error, no se pudo cambiar el permiso de la compartición.",
-    "can edit" : "puede editar",
     "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "No users or groups" : "Sin usuarios ni grupos",
@@ -151,7 +150,7 @@ OC.L10N.register(
     "Invalid location selected" : "Ubicación seleccionada no válida",
     "Attachments folder successfully saved." : "Carpeta de adjuntos guardada correctamente.",
     "Error on saving attachments folder." : "Error al guardar la carpeta de adjuntos.",
-    "Default attachments location" : "Ubicación predeterminada para adjuntos",
+    "Attachments folder" : "Carpeta de archivos adjuntos",
     "{filename} could not be parsed" : "No se pudo analizar {filename}",
     "No valid files found, aborting import" : "No se encontraron archivos válidos, se cancela la importación",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó correctamente %n evento","Se importaron correctamente %n eventos","Se importaron correctamente %n eventos"],
@@ -183,13 +182,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
     "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
     "General" : "General",
-    "Personal availability settings" : "Configuración de disponibilidad personal",
-    "Copy primary CalDAV address" : "Copiar dirección CalDAV principal",
     "Copy iOS/macOS CalDAV address" : "Copiar dirección CalDAV para iOS/macOS",
-    "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
-    "Show tasks in calendar" : "Mostrar tareas en el calendario",
-    "Show weekends" : "Mostrar fines de semana",
-    "Show week numbers" : "Mostrar número de semana",
+    "Appearance" : "Apariencia",
     "Editing" : "Edición",
     "Default reminder" : "Recordatorio predeterminado",
     "Keyboard shortcuts" : "Atajos del teclado",
@@ -477,7 +471,6 @@ OC.L10N.register(
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
     "Add a location" : "Agregar una ubicación",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
@@ -501,12 +494,21 @@ OC.L10N.register(
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
     "Hidden" : "Oculto",
+    "can edit" : "puede editar",
     "Calendar name …" : "Nombre del calendario …",
+    "Default attachments location" : "Ubicación predeterminada para adjuntos",
     "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Resumen de accesos directos",
+    "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
+    "Show tasks in calendar" : "Mostrar tareas en el calendario",
     "Enable simplified editor" : "Habilitar editor simplificado",
     "Limit the number of events displayed in the monthly view" : "Limitar la cantidad de eventos mostrados en la vista mensual",
+    "Show weekends" : "Mostrar fines de semana",
+    "Show week numbers" : "Mostrar número de semana",
     "Time increments" : "Incrementos de tiempo",
-    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado"
+    "Copy primary CalDAV address" : "Copiar dirección CalDAV principal",
+    "Personal availability settings" : "Configuración de disponibilidad personal",
+    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
