@@ -137,12 +137,10 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Equipo)",
     "An error occurred while unsharing the calendar." : "Ocurrió un error al dejar de compartir el calendario.",
     "An error occurred, unable to change the permission of the share." : "Ocurrió un error, no se pudieron cambiar los permisos del recurso compartido.",
-    "can edit" : "puede editar",
     "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "No users or groups" : "Sin usuarios ni grupos",
     "Failed to save calendar name and color" : "No se pudo guardar el nombre ni el color del calendario",
-    "Calendar name …" : "Nombre del calendario …",
     "Never show me as busy (set this calendar to transparent)" : "Nunca mostrarme como ocupado (establecer este calendario como transparente)",
     "Share calendar" : "Compartir calendario",
     "Unshare from me" : "Dejar de compartir conmigo",
@@ -159,7 +157,6 @@ OC.L10N.register(
     "Invalid location selected" : "Ubicación seleccionada inválida",
     "Attachments folder successfully saved." : "La carpeta de adjuntos se guardó exitosamente.",
     "Error on saving attachments folder." : "Ocurrió un error al guardar la carpeta de adjuntos.",
-    "Default attachments location" : "Ubicación predeterminada para adjuntos",
     "{filename} could not be parsed" : "No se pudo analizar {filename}",
     "No valid files found, aborting import" : "No se encontraron archivos válidos, cancelando la importación",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó exitosamente %n evento","Se importaron exitosamente %n eventos","Se importaron exitosamente %n eventos"],
@@ -193,13 +190,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
     "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
     "General" : "General",
-    "Personal availability settings" : "Configuración de disponibilidad personal",
-    "Copy primary CalDAV address" : "Copiar la dirección CalDAV principal",
     "Copy iOS/macOS CalDAV address" : "Copiar la dirección iOS/macOS CalDAV",
-    "Enable birthday calendar" : "Habilitar el calendario de cumpleaños",
-    "Show tasks in calendar" : "Mostrar tareas en el calendario",
-    "Show weekends" : "Mostrar fines de semana",
-    "Show week numbers" : "Mostrar número de semana",
+    "Appearance" : "Apariencia",
     "Editing" : "Editando",
     "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
     "Default reminder" : "Recordatorio predeterminado",
@@ -529,7 +521,6 @@ OC.L10N.register(
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
     "Add a location" : "Añadir ubicación",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
@@ -554,11 +545,21 @@ OC.L10N.register(
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
     "Hidden" : "Oculto",
+    "can edit" : "puede editar",
+    "Calendar name …" : "Nombre del calendario …",
+    "Default attachments location" : "Ubicación predeterminada para adjuntos",
     "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Vista general de atajos",
+    "Enable birthday calendar" : "Habilitar el calendario de cumpleaños",
+    "Show tasks in calendar" : "Mostrar tareas en el calendario",
     "Enable simplified editor" : "Habilitar el editor simplificado",
     "Limit the number of events displayed in the monthly view" : "Limitar el número de eventos mostrados en la vista mensual",
+    "Show weekends" : "Mostrar fines de semana",
+    "Show week numbers" : "Mostrar número de semana",
     "Time increments" : "Incrementos de tiempo",
-    "Show keyboard shortcuts" : "Mostrar atajos de teclado"
+    "Copy primary CalDAV address" : "Copiar la dirección CalDAV principal",
+    "Personal availability settings" : "Configuración de disponibilidad personal",
+    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
