@@ -107,7 +107,6 @@ OC.L10N.register(
     "Delete permanently" : "מחיקה לצמיתות",
     "Could not update calendar order." : "לא היה ניתן לעדכן את סדר לוח השנה.",
     "Deck" : "חפיסה",
-    "Hidden" : "מוסתר",
     "Internal link" : "קישור פנימי",
     "A private link that can be used with external clients" : "קישור פרטי שיכול לשמש עבור משתמשים חיצוניים",
     "Copy internal link" : "העתקת קישור פנימי",
@@ -129,12 +128,10 @@ OC.L10N.register(
     "Deleting share link …" : "מחיקת קישור השיתוף…",
     "An error occurred while unsharing the calendar." : "אירעה שגיאה במהלך ביטול שיתוף לוח השנה",
     "An error occurred, unable to change the permission of the share." : "אירעה שגיאה, לא ניתן לשנות את הרשאות השיתוף.",
-    "can edit" : "ניתן לערוך",
     "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
     "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
     "No users or groups" : "אין משתמשים או קבוצות",
     "Failed to save calendar name and color" : "נכשל בשמירת שם וצבע לוח השנה",
-    "Calendar name …" : "שם לוח השנה ...",
     "Share calendar" : "שיתוף לוח השנה",
     "Unshare from me" : "ביטול השיתוף איתי",
     "Save" : "שמור",
@@ -145,11 +142,12 @@ OC.L10N.register(
     "Calendar to import into" : "לוח שנה לייבוא אליו",
     "Cancel" : "ביטול",
     "_Import calendar_::_Import calendars_" : ["יבוא לוחות שנה","יבוא לוחות שנה","יבוא לוחות שנה"],
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
     "{filename} could not be parsed" : "לא ניתן לפענח את {filename}",
     "No valid files found, aborting import" : "לא נמצאו קבצים תקפים, הייבוא מבוטל",
     "Import partially failed. Imported {accepted} out of {total}." : "הייבוא נכשל חלקית. מיובא {accepted} מתוך {total}.",
     "Automatic" : "אוטומטי",
-    "Automatic ({detected})" : "אוטומטי ({detected})",
+    "Automatic ({timezone})" : "אוטומטי ({timezone})",
     "New setting was not saved successfully." : "ההגדרה החדשה לא נשמרה בהצלחה.",
     "Timezone" : "אזור זמן",
     "Navigation" : "ניווט",
@@ -168,12 +166,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "קישור ה־CalDAV הועתק ללוח הגזירים.",
     "CalDAV link could not be copied to clipboard." : "לא ניתן להעתיק את קישור ה־CalDAV ללוח הגזירים.",
     "General" : "כללי",
-    "Copy primary CalDAV address" : "העתקת כתובת CalDAV עיקרית",
     "Copy iOS/macOS CalDAV address" : "העתקת כתובת CalDAV ל־iOS/macOS",
-    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
-    "Show tasks in calendar" : "הצג משימות בלוח השנה",
-    "Show weekends" : "הצגת סופי שבוע",
-    "Show week numbers" : "הצגת מספרי שבועות",
+    "Appearance" : "מראה",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Update" : "עדכון",
     "Location" : "מיקום",
@@ -267,6 +261,7 @@ OC.L10N.register(
     "Update this occurrence" : "עדכון המופע הזה",
     "Public calendar does not exist" : "לוח השנה הציבורי אינו קיים",
     "Maybe the share was deleted or has expired?" : "אולי השיתוף נמחק או פג תוקפו?",
+    "None" : "ללא",
     "from {formattedDate}" : "מ- {formattedDate}",
     "to {formattedDate}" : "אל {formattedDate}",
     "on {formattedDate}" : "בתאריך {formattedDate}",
@@ -355,7 +350,6 @@ OC.L10N.register(
     "When shared show full event" : "כאשר משותף מציג אירוע מלא",
     "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
     "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
-    "The visibility of this event in shared calendars." : "הנראות של אירוע זה בלוחות שנה משותפים.",
     "Add a location" : "הוסף מיקום",
     "Status" : "מצב",
     "Confirmed" : "מאושר",
@@ -373,8 +367,18 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
     "Imported {filename}" : "יובא {filename} ",
     "User not found" : "המשתמש לא נמצא",
+    "Hidden" : "מוסתר",
+    "can edit" : "ניתן לערוך",
+    "Calendar name …" : "שם לוח השנה ...",
+    "Automatic ({detected})" : "אוטומטי ({detected})",
     "Shortcut overview" : "סקירת קיצור דרך",
+    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
+    "Show tasks in calendar" : "הצג משימות בלוח השנה",
     "Enable simplified editor" : "אפשר עורך פשוט",
-    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת"
+    "Show weekends" : "הצגת סופי שבוע",
+    "Show week numbers" : "הצגת מספרי שבועות",
+    "Copy primary CalDAV address" : "העתקת כתובת CalDAV עיקרית",
+    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
+    "The visibility of this event in shared calendars." : "הנראות של אירוע זה בלוחות שנה משותפים."
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
