@@ -136,7 +136,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Lag)",
     "An error occurred while unsharing the calendar." : "Det oppstod en feil under oppheving av deling av kalenderen.",
     "An error occurred, unable to change the permission of the share." : "En feil oppsto, kan ikke endre rettighetene til delingen.",
-    "can edit" : "kan endre",
     "Unshare with {displayName}" : "Fjern deling med {displayName}",
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
@@ -158,7 +157,7 @@ OC.L10N.register(
     "Invalid location selected" : "Invalid location selected",
     "Attachments folder successfully saved." : "Vedleggsmappen er lagret.",
     "Error on saving attachments folder." : "Feil ved lagring av vedleggsmappe.",
-    "Default attachments location" : "Standard plassering for vedlegg",
+    "Attachments folder" : "Vedleggsmappe",
     "{filename} could not be parsed" : "{filename} kunne ikke leses",
     "No valid files found, aborting import" : "Ingen gyldig filer funnet, avbryter importering",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Vellykket importert %n hendelse","Vellykket importert %n hendelser"],
@@ -192,13 +191,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
     "General" : "Generell",
-    "Personal availability settings" : "Personlig ledighets-innstillinger",
-    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
     "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
-    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
-    "Show tasks in calendar" : "Vis oppgaver i kalender",
-    "Show weekends" : "Vis helger",
-    "Show week numbers" : "Vis ukenummer",
+    "Appearance" : "Utseende",
     "Editing" : "Rediger",
     "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
     "Default reminder" : "Standardpåminnelse",
@@ -526,7 +520,6 @@ OC.L10N.register(
     "When shared show full event" : "Vis hele hendelsen om den deles",
     "When shared show only busy" : "Vis kun opptatt om den deles",
     "When shared hide this event" : "Skjul denne hendelsen om den deles",
-    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere",
     "Add a location" : "Legg til et sted",
     "Status" : "Status",
     "Confirmed" : "Bekreftet",
@@ -552,12 +545,21 @@ OC.L10N.register(
     "Appointment not found" : "Avtale ikke funnet",
     "User not found" : "Fant ikke brukeren",
     "Hidden" : "Skjult",
+    "can edit" : "kan endre",
     "Calendar name …" : "Kalendernavn…",
+    "Default attachments location" : "Standard plassering for vedlegg",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Oversikt over snarveier",
+    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
+    "Show tasks in calendar" : "Vis oppgaver i kalender",
     "Enable simplified editor" : "Aktiver forenklet redigering",
     "Limit the number of events displayed in the monthly view" : "Begrens antall hendelser som vises i månedsvisningen",
+    "Show weekends" : "Vis helger",
+    "Show week numbers" : "Vis ukenummer",
     "Time increments" : "Tidsøkninger",
-    "Show keyboard shortcuts" : "Vis tastatursnarveier"
+    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
+    "Personal availability settings" : "Personlig ledighets-innstillinger",
+    "Show keyboard shortcuts" : "Vis tastatursnarveier",
+    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere"
 },
 "nplurals=2; plural=(n != 1);");
