@@ -138,7 +138,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName}(Team)",
     "An error occurred while unsharing the calendar." : "Er is een fout opgetreden bij het delen van de kalender.",
     "An error occurred, unable to change the permission of the share." : "Er is een fout opgetreden, het is niet mogelijk om de machtiging van de share te wijzigen",
-    "can edit" : "kan wijzigen",
     "Unshare with {displayName}" : "Stop delen met {displayName}",
     "Share with users or groups" : "Deel met gebruikers of groepen",
     "No users or groups" : "Geen gebruikers of groepen",
@@ -160,7 +159,7 @@ OC.L10N.register(
     "Invalid location selected" : "Ongeldige locatie geselecteerd",
     "Attachments folder successfully saved." : "Bijlagenmap succesvol opgeslagen.",
     "Error on saving attachments folder." : "Fout bij het opslaan van de bijlagenmap.",
-    "Default attachments location" : "Standaard bijlagenlocatie",
+    "Attachments folder" : "Bijlagemap",
     "{filename} could not be parsed" : "{filename} kon niet worden geanalyseerd",
     "No valid files found, aborting import" : "Geen geldige bestand gevonden, import afgebroken",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nafspraak succesvol geïmporteerd","%n afspraken succesvol geïmporteerd"],
@@ -194,13 +193,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
     "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
     "General" : "Algemeen",
-    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
-    "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
     "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
-    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
-    "Show tasks in calendar" : "Toon taken in agenda",
-    "Show weekends" : "Toon weekenden",
-    "Show week numbers" : "Tonen weeknummers",
+    "Appearance" : "Uiterlijk",
     "Editing" : "Bewerken",
     "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
     "Default reminder" : "Standaard herinnering",
@@ -534,7 +528,6 @@ OC.L10N.register(
     "When shared show full event" : "Wanneer gedeeld, toon gehele afspraak",
     "When shared show only busy" : "Wanneer gedeeld, toon alleen onbeschikbaarheid",
     "When shared hide this event" : "Wanneer gedeeld, verberg deze afspraak",
-    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's.",
     "Add a location" : "Een locatie toevoegen",
     "Status" : "Status",
     "Confirmed" : "Bevestigd",
@@ -558,12 +551,21 @@ OC.L10N.register(
     "Appointment not found" : "Afspraak niet gevonden",
     "User not found" : "Gebruiker niet gevonden",
     "Hidden" : "Verborgen",
+    "can edit" : "kan wijzigen",
     "Calendar name …" : "Kalendernaam ...",
+    "Default attachments location" : "Standaard bijlagenlocatie",
     "Automatic ({detected})" : "Automatisch ({detected})",
     "Shortcut overview" : "Snelkoppeling overzicht",
+    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
+    "Show tasks in calendar" : "Toon taken in agenda",
     "Enable simplified editor" : "Eenvoudige editor inschakelen",
     "Limit the number of events displayed in the monthly view" : "Beperk het aantal evenementen dat wordt weergegeven in de maandweergave",
+    "Show weekends" : "Toon weekenden",
+    "Show week numbers" : "Tonen weeknummers",
     "Time increments" : "Time-toename",
-    "Show keyboard shortcuts" : "Toon sneltoetsen"
+    "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
+    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
+    "Show keyboard shortcuts" : "Toon sneltoetsen",
+    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's."
 },
 "nplurals=2; plural=(n != 1);");
