@@ -134,7 +134,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Skupina)",
     "An error occurred while unsharing the calendar." : "Prišlo je do napake med onemogočanjem souporabe koledarja.",
     "An error occurred, unable to change the permission of the share." : "Prišlo je do napake; ni mogoče spremeniti dovoljenj souporabe.",
-    "can edit" : "lahko ureja",
     "Unshare with {displayName}" : "Odstrani souporabo z uporabnikom {displayName}",
     "Share with users or groups" : "Souporaba z uporabniki in skupinami",
     "No users or groups" : "Ni uporabnikov ali skupin",
@@ -155,7 +154,7 @@ OC.L10N.register(
     "Invalid location selected" : "Izbrano je neveljavno mesto",
     "Attachments folder successfully saved." : "Mapa prilog je uspešno shranjena.",
     "Error on saving attachments folder." : "Napaka med shranjevanjem mape prilog",
-    "Default attachments location" : "Privzeto mesto prilog",
+    "Attachments folder" : "Mapa prilog",
     "{filename} could not be parsed" : "Datoteke {filename} ni mogoče razčleniti",
     "No valid files found, aborting import" : "Ni najdenih veljavnih datotek, uvoz bo preklican",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Uspešno je uvožen %n dogodek.","Uspešno sta uvožena %n dogodka.","Uspešno so uvoženi %n dogodki.","Uspešno je uvoženih %n dogodkov."],
@@ -188,13 +187,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
     "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
     "General" : "Splošno",
-    "Personal availability settings" : "Nastavitve osebne dejavnosti",
-    "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
     "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
-    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
-    "Show tasks in calendar" : "Pokaži naloge v koledarju",
-    "Show weekends" : "Pokaži vikende",
-    "Show week numbers" : "Pokaži številke tednov",
+    "Appearance" : "Videz",
     "Editing" : "Urejanje",
     "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
     "Default reminder" : "Privzeti opomnik",
@@ -505,7 +499,6 @@ OC.L10N.register(
     "When shared show full event" : "V souporabi pokaži poln dogodek",
     "When shared show only busy" : "V souporabi pokaži le, da je zasedeno",
     "When shared hide this event" : "V souporabi skrij ta dogodek",
-    "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi.",
     "Add a location" : "Dodaj mesto ...",
     "Status" : "Stanje",
     "Confirmed" : "Potrjeno",
@@ -529,12 +522,21 @@ OC.L10N.register(
     "Appointment not found" : "Sestanka ni mogoče najti",
     "User not found" : "Uporabnika ni mogoče najti",
     "Hidden" : "Skrito",
+    "can edit" : "lahko ureja",
     "Calendar name …" : "Ime koledarja …",
+    "Default attachments location" : "Privzeto mesto prilog",
     "Automatic ({detected})" : "Samodejno ({detected})",
     "Shortcut overview" : "Pregled tipkovnih bližnjic",
+    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
+    "Show tasks in calendar" : "Pokaži naloge v koledarju",
     "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
     "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
+    "Show weekends" : "Pokaži vikende",
+    "Show week numbers" : "Pokaži številke tednov",
     "Time increments" : "Časovno povečevanje",
-    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice"
+    "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
+    "Personal availability settings" : "Nastavitve osebne dejavnosti",
+    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
+    "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
