@@ -95,7 +95,6 @@ OC.L10N.register(
     "Delete permanently" : "Xoá vĩnh viễn",
     "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
     "Deck" : "Kế hoạch",
-    "Hidden" : "Ẩn",
     "Internal link" : "Liên kết nội bộ",
     "An error occurred, unable to publish calendar." : "Có lỗi đã xảy ra, không thể công khai lịch.",
     "An error occurred, unable to send email." : "Một lỗi đã xảy ra, không thể gửi email.",
@@ -114,7 +113,6 @@ OC.L10N.register(
     "Delete share link" : "Xóa liên kết chia sẻ",
     "Deleting share link …" : "Đang xóa liên kết chia sẻ  ...",
     "An error occurred, unable to change the permission of the share." : "Một lỗi đã diễn ra, không thể thay đổi quyền hạn chia sẻ",
-    "can edit" : "có thể chỉnh sửa",
     "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
     "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
     "No users or groups" : "Không có người dùng hay nhóm",
@@ -127,13 +125,15 @@ OC.L10N.register(
     "Calendar to import into" : "Lịch để nhập vào",
     "Cancel" : "Hủy",
     "_Import calendar_::_Import calendars_" : ["Nhập lịch"],
+    "Attachments folder" : "Thư mục đính kèm",
     "{filename} could not be parsed" : "{filename} không thể được phân tách",
     "No valid files found, aborting import" : "Không có tệp khả dụng được tìm thấy, đang hủy quá trình nhập",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n sự kiện đã được nhập vào thành công"],
     "Import partially failed. Imported {accepted} out of {total}." : "Quá trình nhập thất bại 1 phần. Đã nhập {accepted} trong tổng {total}.",
     "Automatic" : "Tự động",
-    "Automatic ({detected})" : " ({detected}) tự động",
+    "Automatic ({timezone})" : "Tự động ({timezone})",
     "New setting was not saved successfully." : "Thiết lập mới không được lưu thành công",
+    "Timezone" : "Múi giờ",
     "Navigation" : "Điều hướng",
     "Previous period" : "Kỳ trước",
     "Next period" : "Kỳ tiếp theo",
@@ -149,22 +149,16 @@ OC.L10N.register(
     "Close editor" : "Đóng trình biên tập",
     "Save edited event" : "Lưu lại sự kiện được chỉnh sửa",
     "Delete edited event" : "Xoá sự kiện được chỉnh sửa",
-    "Shortcut overview" : "Bản xem trước của lối tắt",
     "or" : "hoặc",
     "No reminder" : "Không có nhắc hẹn",
     "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
     "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
-    "Enable birthday calendar" : "Bật lịch sinh nhật",
-    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
-    "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
-    "Show weekends" : "Cho thấy ngày cuối tuần",
-    "Show week numbers" : "Hiển thị số tuần",
-    "Time increments" : "Mức tăng thời gian",
-    "Default reminder" : "Nhác hẹn mặc định",
-    "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
+    "General" : "Cài đặt chung",
     "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
-    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
-    "Show keyboard shortcuts" : "Hiển thị các phím tắt",
+    "Appearance" : "Giao diện",
+    "Editing" : "Chỉnh sửa",
+    "Default reminder" : "Nhác hẹn mặc định",
+    "Keyboard shortcuts" : "Phím tắt",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} phút"],
     "0 minutes" : "0 phút",
     "_{duration} hour_::_{duration} hours_" : ["{duration} giờ"],
@@ -312,6 +306,7 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
     "Yes" : "Có",
     "No" : "Không",
+    "None" : "Không có",
     "Create" : "Tạo",
     "from {formattedDate}" : "từ {formattedDate}",
     "to {formattedDate}" : "đến {formattedDate}",
@@ -355,6 +350,7 @@ OC.L10N.register(
     "Close" : "Đóng",
     "Title" : "Tên",
     "Participants" : "Người tham gia",
+    "Submit" : "Gửi",
     "Subscribe to {name}" : "Dõi theo {name}",
     "Export {name}" : "Xuất dữ liệu bảng {name}",
     "Anniversary" : "Ngày kỷ niệm",
@@ -422,7 +418,6 @@ OC.L10N.register(
     "When shared show full event" : "Khi được chia sẻ thì hiển thị đầy đủ sự kiện",
     "When shared show only busy" : "Khi được chia sẻ thì chỉ hiển thị đang bận",
     "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
-    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ",
     "Add a location" : "Thêm vào một địa điểm",
     "Status" : "Trạng thái",
     "Confirmed" : "Đã xác nhận",
@@ -440,6 +435,20 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
     "Imported {filename}" : " {filename} đã được nhập",
     "Appointment not found" : "Không tìm thấy cuộc hẹn",
-    "User not found" : "Không tìm thấy người dùng"
+    "User not found" : "Không tìm thấy người dùng",
+    "Hidden" : "Ẩn",
+    "can edit" : "có thể chỉnh sửa",
+    "Automatic ({detected})" : " ({detected}) tự động",
+    "Shortcut overview" : "Bản xem trước của lối tắt",
+    "Enable birthday calendar" : "Bật lịch sinh nhật",
+    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
+    "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
+    "Show weekends" : "Cho thấy ngày cuối tuần",
+    "Show week numbers" : "Hiển thị số tuần",
+    "Time increments" : "Mức tăng thời gian",
+    "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
+    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
+    "Show keyboard shortcuts" : "Hiển thị các phím tắt",
+    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ"
 },
 "nplurals=1; plural=0;");
